@@ -36,6 +36,8 @@
 #include <libanjuta/interfaces/ianjuta-debugger-instruction.h>
 #include <libanjuta/interfaces/ianjuta-debugger-variable.h>
 
+#include <gio/gio.h>
+
 #include <stdarg.h>
 
 /* Contants defintion
@@ -60,9 +62,10 @@ typedef enum
 	SET_ENVIRONMENT_COMMAND,
 	UNLOAD_COMMAND,         /* Program loaded */
 	START_COMMAND,         
+	CONNECT_COMMAND,         
 	BREAK_LINE_COMMAND,		  /* Program loaded - Program stopped */
-	BREAK_FUNCTION_COMMAND,
-	BREAK_ADDRESS_COMMAND,	/* 0x10 */
+	BREAK_FUNCTION_COMMAND,  /* 0x10 */
+	BREAK_ADDRESS_COMMAND,
 	ENABLE_BREAK_COMMAND,
 	IGNORE_BREAK_COMMAND,
 	CONDITION_BREAK_COMMAND,
@@ -77,8 +80,8 @@ typedef enum
 	STEP_OUT_COMMAND,
 	RUN_COMMAND,		
 	RUN_TO_COMMAND,
-	STEPI_IN_COMMAND,
-	STEPI_OVER_COMMAND,			/* 0x20 */
+	STEPI_IN_COMMAND,			/* 0x20 */
+	STEPI_OVER_COMMAND,
 	RUN_TO_ADDRESS_COMMAND,
 	EXIT_COMMAND,
 	HANDLE_SIGNAL_COMMAND,
@@ -93,8 +96,8 @@ typedef enum
 	INFO_VARIABLES_COMMAND,
 	SET_FRAME_COMMAND,
 	LIST_FRAME_COMMAND,
-	UPDATE_REGISTER_COMMAND,
-	WRITE_REGISTER_COMMAND,		/* 0x30 */
+	UPDATE_REGISTER_COMMAND,	/* 0x30 */
+	WRITE_REGISTER_COMMAND,
 	EVALUATE_COMMAND,
 	INSPECT_COMMAND,
 	PRINT_COMMAND,
@@ -148,6 +151,9 @@ typedef enum
 	DMA_START_COMMAND =
 		START_COMMAND | RUN_PROGRAM |
 		NEED_PROGRAM_LOADED | NEED_PROGRAM_STOPPED,
+	DMA_CONNECT_COMMAND =
+		CONNECT_COMMAND | RUN_PROGRAM |
+		NEED_PROGRAM_LOADED | NEED_PROGRAM_STOPPED,
 	DMA_BREAK_LINE_COMMAND =
 		BREAK_LINE_COMMAND |
 		NEED_PROGRAM_LOADED | NEED_PROGRAM_STOPPED,
@@ -297,6 +303,7 @@ struct _DmaQueueCommand
 			GList *dirs;
 		} load;
 		struct {
+			gchar *server;
 			gchar *args;
 			gboolean terminal;
 			gboolean stop;
@@ -415,6 +422,12 @@ dma_command_new (DmaDebuggerCommand cmd_type,...)
 		cmd->data.start.terminal = va_arg (args, gboolean);
 		cmd->data.start.stop = va_arg (args, gboolean);
 	    break;
+	case CONNECT_COMMAND:
+		cmd->data.start.server = g_strdup (va_arg (args, gchar *));
+		cmd->data.start.args = g_strdup (va_arg (args, gchar *));
+		cmd->data.start.terminal = va_arg (args, gboolean);
+		cmd->data.start.stop = va_arg (args, gboolean);
+	    break;
 	case RUN_COMMAND:
 		break;
 	case RUN_TO_COMMAND:
@@ -622,6 +635,7 @@ dma_command_new (DmaDebuggerCommand cmd_type,...)
 		cmd->user_data = va_arg (args, gpointer);
 		break;
 	}
+	va_end (args);
 
 	return cmd;
 }
@@ -663,6 +677,12 @@ dma_queue_start (DmaDebuggerQueue *self, const gchar *args, gboolean terminal, g
 	return dma_debugger_queue_append (self, dma_command_new (DMA_START_COMMAND, args, terminal, stop));
 }
 
+gboolean
+dma_queue_connect (DmaDebuggerQueue *self, const gchar *server, const gchar *args, gboolean terminal, gboolean stop)
+{
+	return dma_debugger_queue_append (self, dma_command_new (DMA_CONNECT_COMMAND, server, args, terminal, stop));
+}
+
 gboolean
 dma_queue_unload (DmaDebuggerQueue *self)
 {
@@ -1035,6 +1055,8 @@ dma_command_free (DmaQueueCommand *cmd)
 		if (cmd->data.watch.value != NULL) g_free (cmd->data.watch.value);
 		break;
 	case START_COMMAND:
+	case CONNECT_COMMAND:
+		if (cmd->data.start.server) g_free (cmd->data.start.server);
 		if (cmd->data.start.args) g_free (cmd->data.start.args);
 		break;
 	case LOAD_COMMAND:
@@ -1133,7 +1155,7 @@ dma_command_run (DmaQueueCommand *cmd, IAnjutaDebugger *debugger,
 	gboolean ret = FALSE;
 	DmaDebuggerCommandType type = cmd->type & COMMAND_MASK;
 	IAnjutaDebuggerCallback callback = cmd->callback == NULL ? NULL : dma_debugger_queue_command_callback;
-					 
+	GFile* file;
 	switch (type)
 	{
 	case EMPTY_COMMAND:
@@ -1166,11 +1188,14 @@ dma_command_run (DmaQueueCommand *cmd, IAnjutaDebugger *debugger,
 	case START_COMMAND:
 		ret = ianjuta_debugger_start (debugger, cmd->data.start.args, cmd->data.start.terminal, cmd->data.start.stop, err);
 	    break;
+	case CONNECT_COMMAND:
+		ret = ianjuta_debugger_connect (debugger, cmd->data.start.server, cmd->data.start.args, cmd->data.start.terminal, cmd->data.start.stop, err);
+	    break;
 	case RUN_COMMAND:
 		ret = ianjuta_debugger_run (debugger, err);	
 		break;
 	case RUN_TO_COMMAND:
-		ret = ianjuta_debugger_run_to (debugger, cmd->data.pos.file, cmd->data.pos.line, err);	
+		ret = ianjuta_debugger_run_to (debugger, cmd->data.pos.file, cmd->data.pos.line, err);
 		break;
 	case STEP_IN_COMMAND:
 		ret = ianjuta_debugger_step_in (debugger, err);	
@@ -1185,10 +1210,10 @@ dma_command_run (DmaQueueCommand *cmd, IAnjutaDebugger *debugger,
 		ret = ianjuta_debugger_instruction_run_to_address (IANJUTA_DEBUGGER_INSTRUCTION (debugger), cmd->data.pos.address, err);	
 		break;
 	case STEPI_IN_COMMAND:
-		ret = ianjuta_debugger_instruction_step_in (IANJUTA_DEBUGGER_INSTRUCTION (debugger), err);	
+		ret = ianjuta_debugger_instruction_step_in_instruction (IANJUTA_DEBUGGER_INSTRUCTION (debugger), err);	
 		break;
 	case STEPI_OVER_COMMAND:
-		ret = ianjuta_debugger_instruction_step_over (IANJUTA_DEBUGGER_INSTRUCTION (debugger), err);	
+		ret = ianjuta_debugger_instruction_step_over_instruction (IANJUTA_DEBUGGER_INSTRUCTION (debugger), err);	
 		break;
 	case EXIT_COMMAND:
 		ret = ianjuta_debugger_exit (debugger, err);	
@@ -1197,18 +1222,18 @@ dma_command_run (DmaQueueCommand *cmd, IAnjutaDebugger *debugger,
 		ret = ianjuta_debugger_interrupt (debugger, err);	
 		break;
 	case ENABLE_BREAK_COMMAND:
-		ret = ianjuta_debugger_breakpoint_enable (IANJUTA_DEBUGGER_BREAKPOINT (debugger), cmd->data.brk.id, cmd->data.brk.enable, callback, queue, err);	
+		ret = ianjuta_debugger_breakpoint_enable_breakpoint (IANJUTA_DEBUGGER_BREAKPOINT (debugger), cmd->data.brk.id, cmd->data.brk.enable, callback, queue, err);	
 		break;
 	case IGNORE_BREAK_COMMAND:
-		ret = ianjuta_debugger_breakpoint_ignore (IANJUTA_DEBUGGER_BREAKPOINT (debugger), cmd->data.brk.id, cmd->data.brk.ignore, callback, queue, err);	
+		ret = ianjuta_debugger_breakpoint_ignore_breakpoint (IANJUTA_DEBUGGER_BREAKPOINT (debugger), cmd->data.brk.id, cmd->data.brk.ignore, callback, queue, err);	
 		break;
 	case REMOVE_BREAK_COMMAND:
-		ret = ianjuta_debugger_breakpoint_clear (IANJUTA_DEBUGGER_BREAKPOINT (debugger), cmd->data.brk.id, callback, queue, err);	
+		ret = ianjuta_debugger_breakpoint_clear_breakpoint (IANJUTA_DEBUGGER_BREAKPOINT (debugger), cmd->data.brk.id, callback, queue, err);	
 		break;
 	case BREAK_LINE_COMMAND:
 		if (dma_command_is_breakpoint_pending (cmd))
 		{	
-			ret = ianjuta_debugger_breakpoint_set_at_line (IANJUTA_DEBUGGER_BREAKPOINT (debugger), cmd->data.pos.file, cmd->data.pos.line, callback, queue, err);	
+			ret = ianjuta_debugger_breakpoint_set_breakpoint_at_line (IANJUTA_DEBUGGER_BREAKPOINT (debugger), cmd->data.pos.file, cmd->data.pos.line, callback, queue, err);	
 		}
 		else
 		{
@@ -1218,7 +1243,7 @@ dma_command_run (DmaQueueCommand *cmd, IAnjutaDebugger *debugger,
 	case BREAK_FUNCTION_COMMAND:
 		if (dma_command_is_breakpoint_pending (cmd))
 		{	
-			ret = ianjuta_debugger_breakpoint_set_at_function (IANJUTA_DEBUGGER_BREAKPOINT (debugger), cmd->data.pos.file, cmd->data.pos.function, callback, queue, err);	
+			ret = ianjuta_debugger_breakpoint_set_breakpoint_at_function (IANJUTA_DEBUGGER_BREAKPOINT (debugger), cmd->data.pos.file, cmd->data.pos.function, callback, queue, err);	
 		}
 		else
 		{
@@ -1228,7 +1253,7 @@ dma_command_run (DmaQueueCommand *cmd, IAnjutaDebugger *debugger,
 	case BREAK_ADDRESS_COMMAND:
 		if (dma_command_is_breakpoint_pending (cmd))
 		{	
-			ret = ianjuta_debugger_breakpoint_set_at_address (IANJUTA_DEBUGGER_BREAKPOINT (debugger), cmd->data.pos.address, callback, queue, err);	
+			ret = ianjuta_debugger_breakpoint_set_breakpoint_at_address (IANJUTA_DEBUGGER_BREAKPOINT (debugger), cmd->data.pos.address, callback, queue, err);	
 		}
 		else
 		{
@@ -1236,10 +1261,10 @@ dma_command_run (DmaQueueCommand *cmd, IAnjutaDebugger *debugger,
 		}
 		break;
 	case CONDITION_BREAK_COMMAND:
-		ret = ianjuta_debugger_breakpoint_condition (IANJUTA_DEBUGGER_BREAKPOINT (debugger), cmd->data.brk.id, cmd->data.brk.condition, callback, queue, err);	
+		ret = ianjuta_debugger_breakpoint_condition_breakpoint (IANJUTA_DEBUGGER_BREAKPOINT (debugger), cmd->data.brk.id, cmd->data.brk.condition, callback, queue, err);	
 		break;
 	case LIST_BREAK_COMMAND:
-		ret = ianjuta_debugger_breakpoint_list (IANJUTA_DEBUGGER_BREAKPOINT (debugger), callback, queue, err);	
+		ret = ianjuta_debugger_breakpoint_list_breakpoint (IANJUTA_DEBUGGER_BREAKPOINT (debugger), callback, queue, err);	
 		break;
 	case INSPECT_COMMAND:
 		ret = ianjuta_debugger_inspect (debugger, cmd->data.watch.name, callback, queue, err);
@@ -1293,16 +1318,16 @@ dma_command_run (DmaQueueCommand *cmd, IAnjutaDebugger *debugger,
 		ret = ianjuta_debugger_list_frame (debugger, callback, queue, err);	
 		break;
 	case LIST_REGISTER_COMMAND:
-		ret = ianjuta_debugger_register_list (IANJUTA_DEBUGGER_REGISTER (debugger), callback, queue, err);	
+		ret = ianjuta_debugger_register_list_register (IANJUTA_DEBUGGER_REGISTER (debugger), callback, queue, err);	
 		break;
 	case UPDATE_REGISTER_COMMAND:
-		ret = ianjuta_debugger_register_update (IANJUTA_DEBUGGER_REGISTER (debugger), callback, queue, err);	
+		ret = ianjuta_debugger_register_update_register (IANJUTA_DEBUGGER_REGISTER (debugger), callback, queue, err);	
 		break;
 	case WRITE_REGISTER_COMMAND:
 		reg.num = cmd->data.watch.id;
 	    reg.name = cmd->data.watch.name;
 	    reg.value = cmd->data.watch.value;
-		ret = ianjuta_debugger_register_write (IANJUTA_DEBUGGER_REGISTER (debugger), &reg, err);	
+		ret = ianjuta_debugger_register_write_register (IANJUTA_DEBUGGER_REGISTER (debugger), &reg, err);	
 		break;
 	case INSPECT_MEMORY_COMMAND:
 		ret = ianjuta_debugger_memory_inspect (IANJUTA_DEBUGGER_MEMORY (debugger), cmd->data.mem.address, cmd->data.mem.length, callback, queue, err);	
@@ -1356,6 +1381,7 @@ dma_command_callback (DmaQueueCommand *cmd, const gpointer data, GError *err)
 	case QUIT_COMMAND:
 	case ABORT_COMMAND:
 	case START_COMMAND:
+	case CONNECT_COMMAND:
 	case SET_WORKING_DIRECTORY_COMMAND:
 	case SET_ENVIRONMENT_COMMAND:	
 	case RUN_COMMAND:
