@@ -21,6 +21,7 @@
 
 #include <libanjuta/anjuta-debug.h>
 #include <libanjuta/interfaces/ianjuta-macro.h>
+#include <libanjuta/interfaces/ianjuta-document-manager.h>
 
 #define UI_FILE PACKAGE_DATA_DIR"/ui/anjuta-macro.ui"
 #define ICON_FILE "anjuta-macro.png"
@@ -104,7 +105,7 @@ activate_plugin (AnjutaPlugin * plugin)
 	AnjutaUI *ui;
 	MacroPlugin *macro_plugin;
 
-	DEBUG_PRINT ("MacroPlugin: Activating Macro plugin...");
+	DEBUG_PRINT ("%s", "MacroPlugin: Activating Macro plugin...");
 
 	macro_plugin = ANJUTA_PLUGIN_MACRO (plugin);
 	ui = anjuta_shell_get_ui (plugin->shell, NULL);
@@ -120,7 +121,7 @@ activate_plugin (AnjutaPlugin * plugin)
 
 	macro_plugin->editor_watch_id =
 		anjuta_plugin_add_watch (plugin,
-					 "document_manager_current_editor",
+					 IANJUTA_DOCUMENT_MANAGER_CURRENT_DOCUMENT,
 					 value_added_current_editor,
 					 value_removed_current_editor, NULL);
 					 
@@ -134,7 +135,7 @@ deactivate_plugin (AnjutaPlugin * plugin)
 {
 	AnjutaUI *ui = anjuta_shell_get_ui (plugin->shell, NULL);
 
-	DEBUG_PRINT ("MacroPlugin: Deactivating Macro plugin...");
+	DEBUG_PRINT ("%s", "MacroPlugin: Deactivating Macro plugin...");
 
 	anjuta_plugin_remove_watch (plugin,
 								ANJUTA_PLUGIN_MACRO (plugin)->editor_watch_id,
@@ -147,7 +148,7 @@ deactivate_plugin (AnjutaPlugin * plugin)
 static void
 finalize (GObject * obj)
 {
-	GNOME_CALL_PARENT (G_OBJECT_CLASS, finalize, (G_OBJECT (obj)));
+	G_OBJECT_CLASS (parent_class)->finalize (obj);
 }
 
 static void
@@ -157,7 +158,7 @@ dispose (GObject * obj)
 	if (plugin->macro_dialog != NULL)
 		g_object_unref (plugin->macro_dialog);
 	g_object_unref(plugin->macro_db);
-	GNOME_CALL_PARENT (G_OBJECT_CLASS, dispose, (G_OBJECT (obj)));
+	G_OBJECT_CLASS (parent_class)->dispose (obj);
 }
 
 static void
@@ -186,7 +187,6 @@ match_keyword (MacroPlugin * plugin, GtkTreeIter * iter, const gchar *keyword)
 {
 	gchar *name;
 	gint offset = 0;
-	gint pos;
 	
 	gtk_tree_model_get(macro_db_get_model(plugin->macro_db), iter,
 		MACRO_NAME, &name, -1);
@@ -195,14 +195,18 @@ match_keyword (MacroPlugin * plugin, GtkTreeIter * iter, const gchar *keyword)
 		gchar* text = macro_db_get_macro(plugin, plugin->macro_db, iter, &offset);
 		if (plugin->current_editor != NULL && text != NULL)
 		{
-			pos = ianjuta_editor_get_position (IANJUTA_EDITOR(plugin->current_editor),
-			                                   NULL);
+			gint i;
+			IAnjutaIterable *pos =
+				ianjuta_editor_get_position (IANJUTA_EDITOR(plugin->current_editor),
+											 NULL);
 			ianjuta_editor_insert (IANJUTA_EDITOR (plugin->current_editor),
 			                       pos, text, -1, NULL);
+			for (i = 0; i < offset; i++)
+				ianjuta_iterable_next (pos, NULL);
 			ianjuta_editor_goto_position (IANJUTA_EDITOR(plugin->current_editor), 
-			                              pos + offset, 
-			                              NULL);
+			                              pos, NULL);
 			g_free(text);
+			g_object_unref (pos);
 		}
 		return TRUE;
 	}
