@@ -257,7 +257,7 @@ save_dialog_data (RunDialog* dlg)
 
 		file = g_file_new_for_path (filename);
 		uri = g_file_get_uri (file);
-		g_free (file);
+		g_object_unref (file);
 
 		if (uri != NULL)
 		{
@@ -638,7 +638,7 @@ run_dialog_init (RunDialog *dlg, RunProgramPlugin *plugin)
 	g_object_unref (model);
 
 	/* Fill working directory list */
-	g_list_foreach (plugin->recent_dirs, on_add_directory_in_chooser, dlg->dirs);	
+	g_list_foreach (plugin->recent_dirs, on_add_directory_in_chooser, dlg->dirs);
 	if (plugin->recent_dirs != NULL) gtk_file_chooser_set_uri (dlg->dirs, (const char *)plugin->recent_dirs->data);
 	
 	/* Fill target combo box */
@@ -682,9 +682,12 @@ run_dialog_init (RunDialog *dlg, RunProgramPlugin *plugin)
 			}
 			g_list_free (exec_targets);
 		}
-	}
-	g_object_unref (model);
 
+		/* Set a default value for current dir, allowing to find glade file in
+		 * new project created by the wizard without any change */
+		if (plugin->recent_dirs == NULL) gtk_file_chooser_set_uri (dlg->dirs, project_root_uri);
+	}
+	
 	if (plugin->recent_target != NULL)
 	{
 		gchar *local;
@@ -693,6 +696,24 @@ run_dialog_init (RunDialog *dlg, RunProgramPlugin *plugin)
 		gtk_entry_set_text (GTK_ENTRY (GTK_BIN (dlg->target)->child), local);
 		g_free (local);
 	}
+	else
+	{
+		GtkTreeIter iter;
+
+		if (gtk_tree_model_get_iter_first (model, &iter) &&
+			!gtk_tree_model_iter_next (model, &iter))
+		{
+			gchar *default_target;
+
+			gtk_tree_model_get_iter_first (model, &iter);
+			gtk_tree_model_get (model, &iter,
+								0, &default_target,
+								-1);
+			gtk_entry_set_text (GTK_ENTRY (GTK_BIN (dlg->target)->child), default_target);
+			g_free (default_target);
+		}
+	}
+	g_object_unref (model);
 	
 	/* Fill environment variable list */
 	model = GTK_TREE_MODEL (gtk_list_store_new (ENV_N_COLUMNS,
@@ -732,24 +753,43 @@ run_dialog_init (RunDialog *dlg, RunProgramPlugin *plugin)
 	return dlg;
 }
 
+static gint
+run_parameters_dialog_or_try_execute (RunProgramPlugin *plugin, gboolean try_run)
+{
+	RunDialog dlg;
+	gint response;
+	
+	run_dialog_init (&dlg, plugin);
+	const char *target = gtk_entry_get_text (GTK_ENTRY (GTK_BIN (dlg.target)->child));
+	if (try_run && target && *target)
+	{
+		save_dialog_data (&dlg);
+		return GTK_RESPONSE_APPLY;
+	}
+	else
+	{
+		response = gtk_dialog_run (GTK_DIALOG (dlg.win));
+		if (response == GTK_RESPONSE_APPLY)
+		{
+			save_dialog_data (&dlg);
+		}
+		gtk_widget_destroy (dlg.win);
+	}	
+
+	return response;
+}
+
 /* Public functions
  *---------------------------------------------------------------------------*/
 
 gint
 run_parameters_dialog_run (RunProgramPlugin *plugin)
 {
-	RunDialog dlg;
-	gint response;
-	
-	run_dialog_init (&dlg, plugin);
-	
-	response = gtk_dialog_run (GTK_DIALOG (dlg.win));
-	if (response == GTK_RESPONSE_APPLY)
-	{
-		save_dialog_data (&dlg);
-	}
-	gtk_widget_destroy (dlg.win);
-	
-	return response;
+	return run_parameters_dialog_or_try_execute (plugin, FALSE);
 }
 
+gint
+run_parameters_dialog_or_execute (RunProgramPlugin *plugin)
+{
+	return run_parameters_dialog_or_try_execute (plugin, TRUE);
+}
