@@ -682,7 +682,7 @@ sourceview_dispose(GObject *object)
 		g_source_remove (GPOINTER_TO_UINT (node->data));
 	}
 	g_slist_free (cobj->priv->idle_sources);
-
+	
 	sourceview_prefs_destroy(cobj);
 	
 	G_OBJECT_CLASS (parent_class)->dispose (object);
@@ -1972,7 +1972,7 @@ ilanguage_get_language (IAnjutaEditorLanguage *ilanguage, GError **err)
 	GtkSourceLanguage* lang = gtk_source_buffer_get_language(buffer);
 	if (lang)
 	{
-		return gtk_source_language_get_name(lang);
+		return gtk_source_language_get_id(lang);
 	}
 	else
 	{
@@ -2084,16 +2084,10 @@ iassist_show_tips (IAnjutaEditorAssist *iassist, GList* tips, IAnjutaIterable* i
 				   gint char_alignment, GError **err)
 {
 	Sourceview* sv = ANJUTA_SOURCEVIEW(iassist);
-	GtkTextBuffer* buffer = GTK_TEXT_BUFFER (sv->priv->document);
-	GtkTextIter iter;
-	gint tip_position;
-	gtk_text_buffer_get_iter_at_mark (buffer, &iter,
-									  gtk_text_buffer_get_insert (buffer));
+	SourceviewCell* cell = SOURCEVIEW_CELL (ipos);
+	GtkTextIter* iter = sourceview_cell_get_iter(cell);
 	
-	tip_position = gtk_text_iter_get_offset (&iter) - char_alignment;
-	
-	if (tips == NULL)
-		return;
+	g_return_if_fail (tips != NULL);
 	
 	if (!sv->priv->assist_tip)
 	{
@@ -2103,13 +2097,13 @@ iassist_show_tips (IAnjutaEditorAssist *iassist, GList* tips, IAnjutaIterable* i
 		g_object_weak_ref (G_OBJECT(sv->priv->assist_tip),
 		                   (GWeakNotify) on_assist_tip_destroyed,
 		                   sv);
-		assist_tip_move (sv->priv->assist_tip, GTK_TEXT_VIEW (sv->priv->view), tip_position);
+		assist_tip_move (sv->priv->assist_tip, GTK_TEXT_VIEW (sv->priv->view), iter);
 		gtk_widget_show (GTK_WIDGET (sv->priv->assist_tip));
 	}
 	else
 	{
 		assist_tip_set_tips (sv->priv->assist_tip, tips);
-		assist_tip_move (sv->priv->assist_tip, GTK_TEXT_VIEW (sv->priv->view), tip_position);
+		assist_tip_move (sv->priv->assist_tip, GTK_TEXT_VIEW (sv->priv->view), iter);
 	}
 }
 
@@ -2121,6 +2115,13 @@ iassist_cancel_tips (IAnjutaEditorAssist* iassist, GError** err)
 		gtk_widget_destroy (GTK_WIDGET (sv->priv->assist_tip));
 }
 
+static gboolean
+iassist_tip_shown (IAnjutaEditorAssist* iassist, GError** err)
+{
+	Sourceview* sv = ANJUTA_SOURCEVIEW(iassist);
+	return (sv->priv->assist_tip != NULL);
+}
+
 static void
 iassist_iface_init(IAnjutaEditorAssistIface* iface)
 {
@@ -2129,6 +2130,7 @@ iassist_iface_init(IAnjutaEditorAssistIface* iface)
 	iface->get_suggestions = iassist_get_suggestions;
 	iface->show_tips = iassist_show_tips;
 	iface->cancel_tips = iassist_cancel_tips;
+	iface->tip_shown = iassist_tip_shown;
 }
 
 static gboolean
@@ -2235,6 +2237,7 @@ isearch_iface_init(IAnjutaEditorSearchIface* iface)
 }
 
 /* IAnjutaHover */
+static void on_sourceview_hover_destroy (gpointer data, GObject* where_the_data_was);
 static void
 on_sourceview_hover_leave(gpointer data, GObject* where_the_data_was)
 {
@@ -2246,8 +2249,16 @@ on_sourceview_hover_leave(gpointer data, GObject* where_the_data_was)
 		g_object_unref (sv->priv->tooltip_cell);
 		sv->priv->tooltip_cell = NULL;
 	}
+	g_object_weak_unref (G_OBJECT(sv), on_sourceview_hover_destroy, where_the_data_was);
 }
 
+static void
+on_sourceview_hover_destroy (gpointer data, GObject* where_the_data_was)
+{
+	g_object_weak_unref (G_OBJECT(data), on_sourceview_hover_leave, where_the_data_was);
+}
+
+
 static gboolean 
 on_sourceview_hover_over (GtkWidget *widget, gint x, gint y,
 						  gboolean keyboard_tip, GtkTooltip *tooltip,
@@ -2257,11 +2268,11 @@ on_sourceview_hover_over (GtkWidget *widget, gint x, gint y,
 	SourceviewCell* cell;
 	GtkTextIter iter;
 	GtkTextView *text_view = GTK_TEXT_VIEW (widget);
-	gint bx, by, trailing;
+	gint bx, by;
 		
 	gtk_text_view_window_to_buffer_coords (text_view, GTK_TEXT_WINDOW_TEXT,
 											   x, y, &bx, &by);
-	gtk_text_view_get_iter_at_position (text_view, &iter, &trailing, bx, by);
+	gtk_text_view_get_iter_at_location (text_view, &iter, bx, by);
 	
 	cell = sourceview_cell_new (&iter, text_view);
 	
@@ -2272,6 +2283,7 @@ on_sourceview_hover_over (GtkWidget *widget, gint x, gint y,
 	{
 		gtk_tooltip_set_text (tooltip, sv->priv->tooltip);
 		g_object_weak_ref (G_OBJECT (tooltip), on_sourceview_hover_leave, sv);
+		g_object_weak_ref (G_OBJECT (sv), on_sourceview_hover_destroy, tooltip);
 		g_free (sv->priv->tooltip);
 		sv->priv->tooltip = NULL;
 		sv->priv->tooltip_cell = cell;
